#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96, 5724-I82, 5724-M24
# (C) Copyright IBM Corporation 2007, 2011. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

from java.lang import System, String
from com.ibm.wsspi.scripting import ScriptingExtensionHelper


class WsAdmin:

    __connectionStatus = "UNKNOWN"

    CONNECTED = "CONNECTED"
    DISCONNECTED = "DISCONNECTED"
    ERROR = "ERROR"

    def getConnectionStatus (self):
        print ""
        if WsAdmin.__connectionStatus != "UNKNOWN":
            return WsAdmin.__connectionStatus
        if not ScriptingExtensionHelper.getCurrentScriptingConfigService():
            WsAdmin.__connectionStatus = WsAdmin.ERROR
        elif not ScriptingExtensionHelper.getCurrentScriptingAdminClient():
            WsAdmin.__connectionStatus = WsAdmin.DISCONNECTED
        else:
            WsAdmin.__connectionStatus = WsAdmin.CONNECTED
        #endif
        print "The value of connection status is ", WsAdmin.__connectionStatus
        print ""
        return WsAdmin.__connectionStatus
    #enddef
#endclass

def isEmptyString(value):
    stringValue = String(value);
    if (stringValue.length() != 0):
        return "False";
    else:
        return "True";
#endDef

def getObjectArray(value):
    objectArray = [];

    # @todo: do we have a space problem here?
    stringValue = String(value);
    if (stringValue.length() != 0):
        objectArray = value.split(lineSeparator);

    return objectArray;
#endDef


def getCellContext():
    print ""
    cellContext = ""

    try:
        cellContext =  "/Cell:" + System.getProperty("local.cell");
    except:
        print "Cannot get the cell context. The exception type is: ", sys.exc_type, ". The exception description is: ", sys.exc_value

    print "The value of cellContext is ", cellContext
    print ""
    return cellContext
#endDef

def getNodeContext(userContext):
    print ""
    nodeContext = ""

    if (userContext == "use-local-server"):
        nodeName = System.getProperty("local.node");
    else:
        nodeName = getNamedValue(userContext, "nodes");

    if (isEmptyString(nodeName) == "False"):
        nodeContext =  "/Node:" + nodeName;

    print "The value of nodeContext is ", nodeContext
    print ""
    return nodeContext
#endDef

def getCellName():
    print ""
    cellName = "";

    try:
        cellName = System.getProperty("local.cell")
    except:
        print "Cannot get the cell name. The exception type is: ", sys.exc_type, ". The exception description is: ", sys.exc_value
        raise RuntimeError, "Cannot get the cell name."
    return cellName;
#endDef

def getLocalNodeName():
    print ""
    nodeName = "";

    try:
        nodeName = System.getProperty("local.node")
    except:
        print "Cannot get the node name. The exception type is: ", sys.exc_type, ". The exception description is: ", sys.exc_value
        raise RuntimeError, "Cannot get the node name."
    return nodeName;
#endDef

def getLocalServerName():
    print "";
    nodeID = AdminConfig.getid(getCellContext() + getNodeContext("use-local-server"));
    servers = getObjectArray(AdminConfig.list("Server", nodeID));
    serverName = "";

    print "The value of servers is ", servers

    # Look for the DEPLOYMENT_MANAGER first
    for server in servers:
        servertype = AdminConfig.showAttribute(server, "serverType");
        if (servertype == "DEPLOYMENT_MANAGER"):
            print "servertype is ", servertype
            serverName = AdminConfig.showAttribute(server, "name");
            break;

    #If DEPLOYMENT_MANAGER not found, look for the first APPLICATION_SERVER
    #assumption: for local server there would be only one application server on a local node. this is used only in stand-alone cell
    if( serverName == ""):
        for server in servers:
            serverType = AdminConfig.showAttribute(server, "serverType");
            if (serverType == "APPLICATION_SERVER"):
                print "servertype is ", servertype
                serverName = AdminConfig.showAttribute(server, "name");
                break;

    print "The value of serverName is ", serverName;
    print "";
    return serverName;
#endif

def getCellType():
	print ""
	cellType = ""
	try:
		print "getting cellID"
		cellID = AdminConfig.list("Cell");
		print "cellID : ", cellID
		
		print "getting cell type"
		cellType = AdminConfig.showAttribute(cellID, 'cellType');
		print "cellType :", cellType
	except:
		print "Unable to get cell type - exception: ", sys.exc_type, sys.exc_value
	
	return cellType
#endDef

def isDMgrNode():
    print ""
    isDMgrNode = "False"

    try:
        nodeNameParam = '[-nodeName ' + System.getProperty("local.node") + ']'

        print "The value of nodeNameParam is ", nodeNameParam
        servers = AdminTask.listServers(nodeNameParam).split(System.getProperty("line.separator"));
        print "The value of servers is ", servers

        for server in servers:
            servertype = AdminConfig.showAttribute(server, "serverType");
            print "The value of servertype is ", servertype
            if (servertype == "DEPLOYMENT_MANAGER"):
                isDMgrNode = "True"
                break;

    except:
        print "Cannot find the node type. The exception type is: ", sys.exc_type, ". The exception description is: ", sys.exc_value

    print "The value of isDMgrNode is ", isDMgrNode
    print ""
    return isDMgrNode
#endDef


#*******************************************************************************************************
# main
#*******************************************************************************************************
print "*************************************************************************************"
print "Start: Configure REST Gateway Services"
print ""
print ""

wsadmin = WsAdmin()

if (wsadmin.getConnectionStatus() == WsAdmin.ERROR):
    print "Error: the required connection cannot be established"
else:
    try:
        cellType = getCellType();

        serverName = getLocalServerName();
        print "The value of serverName is ", serverName

        nodeName = getLocalNodeName();
        print "The value of nodeName is ", nodeName

        if (cellType == "STANDALONE"):
            print "Configuring the REST Gateway default services."
            AdminTask.updateRESTGatewayService(['-nodeName', nodeName, '-serverName', serverName, '-enable', 'true'])
            AdminConfig.save();
            print ""
            print "*************************************************************************************"
            print "The REST Gateway services configuration is complete."
            print "*************************************************************************************"
            print ""

        elif (cellType == "DISTRIBUTED"):
            print "Updating the distributed (dmgr or customized) profile"
            # check whether the local node is a deployment manager Node
            isDMgrNode = isDMgrNode();

            if (isDMgrNode != "False"):
                print "The distributed profile does not need an update."

            else:
                print "The distributed custom profile does not need an update."
    except:
        print ""
        print "*************************************************************************************"
        print "The REST Gateway Services cannot be configured. The exception type is: ", sys.exc_type, ". The exception description is: ", sys.exc_value
        print "*************************************************************************************"
        print ""
        raise

print ""
print "end: Configure REST Gateway Services"
print "*************************************************************************************"

